==> nextcloud-23.0.12p0.tgz: nextcloud/apps/updatenotification/l10n/zh_HK.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "新版本 {version} 推出了，可以更新。",
    "Channel updated" : "頻道已更新",
    "Web updater is disabled" : "Web updater 已停用",
    "Update notifications" : "更新通告",
    "The update server could not be reached since %d days to check for new updates." : "已經有 %d 天無法連線更新伺服器以檢查是否有新更新。",
    "Please check the Nextcloud and server log files for errors." : "請參考 Nextcloud 和伺服器記錄檔案以獲取錯誤詳細信息。",
    "Update to %1$s is available." : "更新版 %1$s 已經推出。",
    "Update for %1$s to version %2$s is available." : "%1$s 的更新版 %2$s 已推出。",
    "Update for {app} to version %s is available." : "{app} 的更新版 %s 已推出。",
    "Update notification" : "更新通告",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "顯示 Nextcloud 的更新通告，並為更新程式提供 SSO。",
    "Update" : "更新",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "您使用的版本已不再維護。請盡快更新到有支援的版本。",
    "Apps missing compatible version" : "應用程式缺少兼容版本",
    "View in store" : "在商店中檢視",
    "Apps with compatible version" : "具有兼容版本的應用程式",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "請注意，不建議使用超過 100 個用戶的網絡更新程序！ 請改用命令行更新程序！",
    "Open updater" : "打開更新程式",
    "Download now" : "立即下載",
    "Please use the command line updater to update." : "請使用命令行更新程序進行更新。",
    "What's new?" : "有什麼新鮮事？",
    "The update check is not yet finished. Please refresh the page." : "更新檢查未完成。請重新整理此頁面。",
    "Your version is up to date." : "您的版本是最新版。",
    "A non-default update server is in use to be checked for updates:" : "此非默認更新伺服器用於檢查更新：",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "您可以變更下方的更新頻道，這也會影響應用程式管理頁面。例如，切換到測試版頻道後，在應用程式管理頁更新應用程式時也會提供測試版。",
    "Update channel:" : "更新頻道：",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "您可以更新到新版本，但無法降級到較穩定的版本。",
    "Notify members of the following groups about available updates:" : "有可用更新時通知這些以下群組的成員：",
    "Only notifications for app updates are available." : "只有應用程式更新通知可用。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選定的更新通道將會讓伺服器專用的通知過時。",
    "The selected update channel does not support updates of the server." : "選定的更新頻道不支援伺服器更新。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新版本可用：<strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "請注意，新版本推出後，僅會在有第一個次要版本或更新的版本時顯示。我們會逐步向用戶推送新版本，並在發現問題時跳過特定版本。在 {link} 取得關於更新與推出頻道的更多資訊",
    "Checked on {lastCheckedDate}" : "上次檢查日期：{lastCheckedDate}",
    "Checking apps for compatible versions" : "檢查應用程式的兼容版本",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "請確定您的 config.php 中並沒有將 <samp>appstoreenabled</samp> 的值設定為 false。",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "無法連接到 App Store 或根本沒有返回任何更新。手動搜索更新或確保您的伺服器可以訪問互聯網並且可以連接到 App Store。",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>所有</strong>應用程式都具有適用於此Nextcloud版本的兼容版本。",
    "View changelog" : "檢視版本更新紀錄",
    "Enterprise" : "企業",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "企業用。一律提供最新的修補程式等級，但不會立刻更新到下一個主要版本。一旦 Nextcloud GmbH 完成對大規模與關鍵任務部署的額外強化與測試，才會進行更新。此頻道僅供客戶使用，並提供 Nextcloud Enterprise 軟體包。",
    "Stable" : "穩定",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新的穩定版本。適於一般使用，亦將一律更新到最新主要版本。",
    "Beta" : "Beta 測試版",
    "A pre-release version only for testing new features, not for production environments." : "預發佈版本僅用於測試新功能，不適用於生產環境。",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> 個應用程式沒有適用於此 Nextcloud 版本的兼容版本。"],
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>所有</strong>應用程式都具有適用於此Nextcloud版本的兼容版本",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong> 個應用程式沒有適用於此 Nextcloud 版本的兼容版本"]
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.11p0.tgz: nextcloud/apps/updatenotification/l10n/zh_HK.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "新版本 {version} 推出了，可以更新。",
    "Channel updated" : "頻道已更新",
    "Web updater is disabled" : "Web updater 已停用",
    "Update notifications" : "更新通告",
    "The update server could not be reached since %d days to check for new updates." : "已經有 %d 天無法連線更新伺服器以檢查是否有新更新。",
    "Please check the Nextcloud and server log files for errors." : "請參考 Nextcloud 和伺服器記錄檔案以獲取錯誤詳細信息。",
    "Update to %1$s is available." : "更新版 %1$s 已經推出。",
    "Update to {serverAndVersion} is available." : "{serverAndVersion} 的更新版已推出。",
    "Update for {app} to version %s is available." : "{app} 的更新版 %s 已推出。",
    "Update notification" : "更新通告",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "顯示 Nextcloud 的更新通告，並為更新程式提供 SSO。",
    "Update" : "更新",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "您使用的版本已不再維護。請盡快更新到有支援的版本。",
    "Apps missing compatible version" : "應用程式缺少兼容版本",
    "View in store" : "在商店中檢視",
    "Apps with compatible version" : "具有兼容版本的應用程式",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "請注意，不建議使用超過 100 個用戶的網絡更新程序！ 請改用命令行更新程序！",
    "Open updater" : "打開更新程式",
    "Download now" : "立即下載",
    "Please use the command line updater to update." : "請使用命令行更新程序進行更新。",
    "What's new?" : "有什麼新鮮事？",
    "The update check is not yet finished. Please refresh the page." : "更新檢查未完成。請重新整理此頁面。",
    "Your version is up to date." : "您的版本是最新版。",
    "A non-default update server is in use to be checked for updates:" : "此非默認更新伺服器用於檢查更新：",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "您可以變更下方的更新頻道，這也會影響應用程式管理頁面。例如，切換到測試版頻道後，在應用程式管理頁更新應用程式時也會提供測試版。",
    "Update channel:" : "更新頻道：",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "您可以更新到新版本，但無法降級到較穩定的版本。",
    "Notify members of the following groups about available updates:" : "有可用更新時通知這些以下群組的成員：",
    "Only notifications for app updates are available." : "只有應用程式更新通知可用。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "所選的更新頻道導致伺服器的專用通知過時。",
    "The selected update channel does not support updates of the server." : "選定的更新頻道不支援伺服器更新。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新版本可用：<strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "請注意，新版本推出後，僅會在有第一個次要版本或更新的版本時顯示。我們會逐步向用戶推送新版本，並在發現問題時跳過特定版本。在 {link} 取得關於更新與推出頻道的更多資訊",
    "Checked on {lastCheckedDate}" : "上次檢查日期：{lastCheckedDate}",
    "Checking apps for compatible versions" : "檢查應用程式的兼容版本",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "請確定您的 config.php 中並沒有將 <samp>appstoreenabled</samp> 的值設定為 false。",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "無法連接到 App Store 或根本沒有返回任何更新。手動搜索更新或確保您的伺服器可以訪問互聯網並且可以連接到 App Store。",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>所有</strong>應用程式都具有適用於此Nextcloud版本的兼容版本。",
    "View changelog" : "檢視版本更新紀錄",
    "Enterprise" : "企業",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "企業用。一律提供最新的修補程式等級，但不會立刻更新到下一個主要版本。一旦 Nextcloud GmbH 完成對大規模與關鍵任務部署的額外強化與測試，才會進行更新。此頻道僅供客戶使用，並提供 Nextcloud Enterprise 軟體包。",
    "Stable" : "穩定",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新的穩定版本。適於一般使用，亦將一律更新到最新主要版本。",
    "Beta" : "Beta 測試版",
    "A pre-release version only for testing new features, not for production environments." : "預發佈版本僅用於測試新功能，不適用於生產環境。",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> 個應用程式沒有適用於此 Nextcloud 版本的兼容版本。"],
    "Update for %1$s to version %2$s is available." : "%1$s 的更新版 %2$s 已推出。"
},
"nplurals=1; plural=0;");
